@@ -1,28 +1,29 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
+##
 ##   Distribution clean script for packaging
-##   Last updated on January 6, 2025
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##   Last updated on March 25, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
+
 find . -name .git -print0 | xargs -0 rm -rf
 find . -name .svn -print0 | xargs -0 rm -rf
 find . -name CVS -print0 | xargs -0 rm -rf
@@ -41,18 +42,21 @@ chmod a+x integration/*.sh
 chmod a+x integration/unsupported/*.sh
 chmod a+x manuals/sources/*.sh
 chmod a+x scripts/*.sh
+chmod a+x scripts/embedding/ciao/*.sh
+chmod a+x scripts/embedding/cxprolog/*.sh
 chmod a+x scripts/embedding/eclipse/*.sh
 chmod a+x scripts/embedding/gprolog/*.sh
 chmod a+x scripts/embedding/jiprolog/*.sh
-chmod a+x scripts/embedding/xvm/*.sh
 chmod a+x scripts/embedding/sicstus/*.sh
 chmod a+x scripts/embedding/swipl/*.sh
 chmod a+x scripts/embedding/trealla/*.sh
 chmod a+x scripts/embedding/xsb/*.sh
+chmod a+x scripts/embedding/xvm/*.sh
 chmod a+x scripts/embedding/yap/*.sh
 chmod a+x scripts/debian/postinst
 chmod a+x scripts/debian/prerm
 chmod a+x scripts/debian/postrm
+chmod a+x scripts/docker/portable/*.sh
 chmod a+x scripts/docker/swi-prolog/*.sh
 chmod a+x scripts/linux/*.sh
 chmod a+x scripts/macos/postflight
