@@ -1,30 +1,30 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
+##
 ##   Allure report generator script
-##   Last updated on August 7, 2024
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##   Last updated on March 23, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
 print_version() {
-	echo "$(basename "$0") 0.13"
+	echo "$(basename "$0") 0.14"
 	exit 0
 }
 
@@ -39,15 +39,15 @@ single_file="false"
 environment_pairs=""
 
 if ! [ -x "$(command -v allure)" ] ; then
-	echo "Error: allure is not installed!" >&2
+	echo "Error: Cannot find the allure command-line tool!" >&2
+	echo "See https://allurereport.org/docs/ for installation instructions." >&2
 	exit 1
 elif ! [ "$(printf '%s\n' "$minimal_version" "$(allure --version)" | sort -V | head -n1)" = "$minimal_version" ] ; then
 	echo "Warning: allure $minimal_version or later version is recommended!"
 fi
 
-usage_help()
-{
-	echo 
+usage_help() {
+	echo
 	echo "This script generates Allure reports from test results."
 	echo
 	echo "Usage:"
@@ -68,8 +68,7 @@ usage_help()
 	echo
 }
 
-while getopts "vd:i:o:t:psh" option
-do
+while getopts "vd:i:o:t:psh" option; do
 	case $option in
 		v) print_version;;
 		d) d_arg="$OPTARG";;
@@ -78,8 +77,8 @@ do
 		t) t_arg="$OPTARG";;
 		p) p_arg="true";;
 		s) s_arg="true";;
-		h) usage_help; exit;;
-		*) usage_help; exit;;
+		h) usage_help; exit 0;;
+		*) usage_help; exit 1;;
 	esac
 done
 
@@ -118,8 +117,8 @@ if [ -d "$report" ] && [ -n "$(ls -A "$report")" ] ; then
 		[ -e "$report/favicon.ico" ] && [ -e "$report/index.html" ] && [ -e "$report/styles.css" ] ; then
 		echo "Warning: Overriding previous report..."
 	else
-		echo "Error! Specified report directory is not empty and does not contain a previous"
-		echo "       report. Terminating the script execution to prevent any data loss."
+		echo "Error! Specified report directory is not empty and does not contain a previous" >&2
+		echo "       report. Terminating the script execution to prevent any data loss." >&2
 		exit 1
 	fi
 fi
@@ -173,7 +172,7 @@ fi
 executor=$(cat <<EOF
 {
 	"buildOrder": "$next_build",
-	"buildName": "logtalk_allure_report#$next_build", 
+	"buildName": "logtalk_allure_report#$next_build",
 	"name": "logtalk_tester",
 	"type": "logtalk_tester"
 }
