@@ -1,26 +1,26 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
+##
 ##   Unit testing automation script
-##   Last updated on October 11, 2024
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##   Last updated on March 23, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
 # loosely based on a unit test automation script contributed by Parker Jones
@@ -33,7 +33,7 @@ function cleanup {
 trap cleanup EXIT
 
 print_version() {
-	echo "$(basename "$0") 20.0"
+	echo "$(basename "$0") 20.1"
 	exit 0
 }
 
@@ -176,7 +176,7 @@ run_testset() {
 			echo -n "$(cut -f 5 <<< "$line")"
 			echo -n ' passed, '
 			echo -n "$(cut -f 6 <<< "$line")"
-			echo -n ' failed ('		
+			echo -n ' failed ('
 			echo -n "$(cut -f 7 <<< "$line")"
 			echo ' flaky)'
 			duration=$(( $(date +%s) - start_time ))
@@ -291,9 +291,8 @@ ensure_format_report() {
 	fi
 }
 
-usage_help()
-{
-	echo 
+usage_help() {
+	echo
 	echo "This script automates running unit tests found in the current directory and"
 	echo "recursively in its sub-directories by scanning by default for \"tester.lgt\""
 	echo "and \"tester.logtalk\" source files. In case of failed unit tests or test set"
@@ -322,7 +321,7 @@ usage_help()
 	echo "  -t timeout in seconds for running each test set (default is $timeout; i.e. disabled)"
 	echo "  -n name of the test driver and sourced files (minus file name extensions; default is $driver)"
 	echo "  -s suppress path prefix (default is $prefix)"
-	echo "  -b bug report server (valid values are github and gitlab; no default)"
+	echo "  -b bug report server (valid values are github and gitlab; no default; requires -u option)"
 	echo "  -u base URL to generate links to test files (no default)"
 	echo "  -c code coverage report (default is $coverage)"
 	echo "     (valid values are none and xml)"
@@ -339,8 +338,7 @@ usage_help()
 	echo
 }
 
-while getopts "vp:o:m:f:d:t:n:s:b:u:c:l:e:g:r:i:wh" option
-do
+while getopts "vp:o:m:f:d:t:n:s:b:u:c:l:e:g:r:i:wh" option; do
 	case $option in
 		v) print_version;;
 		p) p_arg="$OPTARG";;
@@ -360,7 +358,7 @@ do
 		g) g_arg="$OPTARG";;
 		r) r_arg="$OPTARG";;
 		w) wipe='true';;
-		h) usage_help; exit;;
+		h) usage_help; exit 0;;
 		*) usage_help; exit 1;;
 	esac
 done
@@ -404,7 +402,7 @@ elif [ "$p_arg" == "xvm" ] ; then
 	prolog='XVM'
 	logtalk=xvmlgt$extension
 	logtalk_call="$logtalk $i_arg -g"
-	case "$i_arg" in 
+	case "$i_arg" in
 		*"--standard-top-level"*) dot=".";;
 		*"--custom-top-level"*) dot="?";;
 		*) dot=".";;
@@ -505,7 +503,7 @@ elif [ "$c_arg" != "" ] ; then
 fi
 
 if [ "$d_arg" != "" ] ; then
-	results="$d_arg"
+	results=$(realpath "$d_arg" 2>/dev/null || echo "$d_arg")
 fi
 
 if [ "$t_arg" != "" ] ; then
@@ -517,20 +515,30 @@ if [ "$s_arg" != "" ] ; then
 fi
 
 if [ "$b_arg" != "" ] ; then
-	issue_server="$(echo "$b_arg" | cut -d':' -f1)"
-	labels="$(echo "$b_arg" | cut -d':' -f2)"
-	if [ "$labels" != "" ] && [ "$labels" != "$issue_server" ] ; then
-		issue_labels="$labels"
+	if [ "$u_arg" == "" ] ; then
+		echo "Error! Issue tracker option (-b) requires the base URL (-u) option" >&2
+		usage_help
+		exit 1
 	fi
+	issue_server="$(echo "$b_arg" | cut -d':' -f1)"
 	if [ "$issue_server" != "github" ] && [ "$issue_server" != "gitlab" ] ; then
 		echo "Error! Issue tracker server must be either github or gitlab: $b_arg" >&2
 		usage_help
 		exit 1
-	fi		
+	fi
+	labels="$(echo "$b_arg" | cut -d':' -f2)"
+	if [ "$labels" != "" ] && [ "$labels" != "$issue_server" ] ; then
+		issue_labels="$labels"
+	fi
 fi
 
 if [ "$u_arg" != "" ] ; then
-	url="$u_arg"
+    if [[ ! "$u_arg" =~ ^https?:// ]] ; then
+        echo "Error! Base URL must start with http:// or https://" >&2
+        usage_help
+        exit 1
+    fi
+    url="$u_arg"
 fi
 
 if [ "$n_arg" != "" ] ; then
@@ -645,12 +653,15 @@ skipped=0
 passed=0
 failed=0
 flaky=0
+temp_file=$(mktemp)
+grep -s '^object' ./*.totals > "$temp_file"
 while read -r line ; do
 	skipped=$((skipped+$(cut -f 4 <<< "$line")))
 	passed=$((passed+$(cut -f 5 <<< "$line")))
 	failed=$((failed+$(cut -f 6 <<< "$line")))
 	flaky=$((flaky+$(cut -f 7 <<< "$line")))
-done < <(grep -s '^object' ./*.totals)
+done < "$temp_file"
+rm -f "$temp_file"
 total=$((skipped+passed+failed))
 
 if grep -q -s -a -h '^!' -- *.errors || grep -q -s -a -h '^!' -- *.results || grep -q -s -a -h '^\*' -- *.errors || grep -q -s -a -h '^\*' -- *.results ; then
