@@ -1,28 +1,29 @@
 #!/bin/sh
 
 #############################################################################
-## 
+##
 ##   Logtalk user folder setup script
-##   Last updated on November 27, 2023
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##   Last updated on March 24, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
+
 echo
 echo "This script copies all the Logtalk per-user files and directories to the"
 echo "user home directory. The location can be set by defining the LOGTALKUSER"
@@ -74,7 +75,7 @@ then
 	echo
 fi
 
-if [ "$LOGTALKHOME" = "$LOGTALKUSER" ]; then 
+if [ "$LOGTALKHOME" = "$LOGTALKUSER" ]; then
 	echo "The environment variables LOGTALKHOME and LOGTALKUSER point"
 	echo "to the same directory! Running this script is not necessary!"
 	exit
@@ -121,7 +122,6 @@ fi
 
 echo "Copying Logtalk files and directories..."
 mkdir -p "$LOGTALKUSER"/contributions
-mkdir -p "$LOGTALKUSER"/docs
 mkdir -p "$LOGTALKUSER"/examples
 mkdir -p "$LOGTALKUSER"/library
 mkdir -p "$LOGTALKUSER"/ports
@@ -129,7 +129,6 @@ mkdir -p "$LOGTALKUSER"/scratch
 mkdir -p "$LOGTALKUSER"/tests
 mkdir -p "$LOGTALKUSER"/tools
 cp -RL "$LOGTALKHOME"/contributions "$LOGTALKUSER"/
-cp -RL "$LOGTALKHOME"/docs "$LOGTALKUSER"/
 cp -RL "$LOGTALKHOME"/examples "$LOGTALKUSER"/
 cp -RL "$LOGTALKHOME"/library "$LOGTALKUSER"/
 cp -RL "$LOGTALKHOME"/ports "$LOGTALKUSER"/
@@ -142,7 +141,9 @@ cp "$LOGTALKHOME"/tester-sample.lgt "$LOGTALKUSER"/tester-sample.lgt
 cp "$LOGTALKHOME"/tests-sample.lgt "$LOGTALKUSER"/tests-sample.lgt
 cp "$LOGTALKHOME"/VERSION.txt "$LOGTALKUSER"/
 chmod -R u+w "$LOGTALKUSER"
+rm -f "$LOGTALKUSER"/tools/diagrams/lgt2*
 rm -f "$LOGTALKUSER"/tools/lgtdoc/xml/lgt2*
+rm -f "$LOGTALKUSER"/tools/packs/lgtenv*
 ln -sf "$LOGTALKHOME"/ACKNOWLEDGMENTS.md "$LOGTALKUSER"/ACKNOWLEDGMENTS.md
 ln -sf "$LOGTALKHOME"/BIBLIOGRAPHY.bib "$LOGTALKUSER"/BIBLIOGRAPHY.bib
 ln -sf "$LOGTALKHOME"/CONTRIBUTING.md "$LOGTALKUSER"/CONTRIBUTING.md
@@ -155,6 +156,7 @@ ln -sf "$LOGTALKHOME"/RELEASE_NOTES.md "$LOGTALKUSER"/RELEASE_NOTES.md
 ln -sf "$LOGTALKHOME"/UPGRADING.md "$LOGTALKUSER"/UPGRADING.md
 ln -sf "$LOGTALKHOME"/adapters "$LOGTALKUSER"/adapters
 ln -sf "$LOGTALKHOME"/coding "$LOGTALKUSER"/coding
+ln -sf "$LOGTALKHOME"/docs "$LOGTALKUSER"/docs
 ln -sf "$LOGTALKHOME"/integration "$LOGTALKUSER"/integration
 ln -sf "$LOGTALKHOME"/manuals "$LOGTALKUSER"/manuals
 ln -sf "$LOGTALKHOME"/paths "$LOGTALKUSER"/paths
