@@ -1,28 +1,28 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
+##
 ##   Logtalk script for updating the HTML core, library, tools, ports,
 ##   contributions, and (optionally) packs documentation
-## 
-##   Last updated on November 2, 2024
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##
+##   Last updated on March 24, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
 
@@ -68,14 +68,13 @@ set_goal() {
 }
 
 print_version() {
-	echo "$(basename "$0") 0.26"
+	echo "$(basename "$0") 0.28"
 	exit 0
 }
 
 
-usage_help()
-{
-	echo 
+usage_help() {
+	echo
 	echo "This script updates the HTML documentation of the core entities, library,"
 	echo "developer tools, ports, contributions, and optionally installed packs."
 	echo
@@ -94,14 +93,13 @@ usage_help()
 }
 
 
-while getopts "vip:m:d:h" option
-do
+while getopts "vip:m:d:h" option; do
 	case $option in
 		v) print_version;;
 		p) p_arg="$OPTARG";;
 		i) include_packs='true';;
-		h) usage_help; exit;;
-		*) usage_help; exit;;
+		h) usage_help; exit 0;;
+		*) usage_help; exit 1;;
 	esac
 done
 
@@ -151,16 +149,35 @@ else
 	cp _templates/layout_no_packs.html _templates/layout.html
 fi
 mv _conf.py conf.py
+
 make clean
 make html
 make info
 make latexpdf
 make epub
+make singlehtml
 #make linkcheck
+
+version_base=$(cat ../../VERSION.txt | cut -f1 -d"-")
+pandoc _build/singlehtml/index.html --wrap=none -t gfm-raw_html -o _build/singlehtml/LogtalkAPIs-$version_base.md
+
+# Handle sed differences between GNU and BSD
+case $(sed --help 2>&1) in
+	*GNU*) sed_i () { sed -i "$@"; };;
+	*) sed_i () { sed -i '' "$@"; };;
+esac
+
+# Remove heading link references from the Markdown file
+sed_i -E 's/\[.\]\(#[-a-z0-9]+ "Link to this heading"\)//g' _build/singlehtml/LogtalkAPIs-$version_base.md
+# Remove other links leaving only the text
+sed_i -E 's/\[([^]]+)\]\([^)]+\)/\1/g' _build/singlehtml/LogtalkAPIs-$version_base.md
+
 cp -R _build/html/* ../
 cp _build/texinfo/LogtalkAPIs-*.info ../
 cp _build/latex/LogtalkAPIs-*.pdf ../
 cp _build/epub/LogtalkAPIs-*.epub ../
+cp _build/singlehtml/LogtalkAPIs-*.md ../
+
 make clean
 rm _templates/layout.html
 mv conf.py _conf.py
